@@ -21,6 +21,7 @@
 #include "H5PropList.h"
 #include "H5Location.h"
 #include "H5Object.h"
+#include "H5OcreatProp.h"
 #include "H5DcreatProp.h"
 #include "H5DxferProp.h"
 #include "H5FaccProp.h"
@@ -67,17 +68,28 @@ H5Location::H5Location() : IdComponent() {}
 //		object.
 // Parameters	object_id - IN: Id of an existing HDF5 object
 // Programmer	Binh-Minh Ribler - 2000
+
+// *** Deprecation warning ***
+// This constructor is no longer appropriate because the data member "id" had
+// been moved to the sub-classes.  It will be removed in 1.10 release.  If its
+// removal does not raise any problems in 1.10, it will be removed from 1.8 in
+// subsequent releases.
 //--------------------------------------------------------------------------
-H5Location::H5Location(const hid_t object_id) : IdComponent(object_id) {}
+H5Location::H5Location(const hid_t object_id) : IdComponent() {}
 
 //--------------------------------------------------------------------------
 // Function:	H5Location copy constructor
-///\brief	Copy constructor: makes a copy of the original H5Location
-///		instance.
+// Purpose:	This noop copy constructor is removed as a result of the data
+//		member "id" being moved down to sub-classes. (Mar 2015)
 ///\param	original - IN: H5Location instance to copy
 // Programmer	Binh-Minh Ribler - 2000
+//
+// *** Deprecation warning ***
+// This constructor is no longer appropriate because the data member "id" had
+// been moved to the sub-classes.  It is removed from 1.8.15 because it is
+// a noop and it can be generated by the compiler if needed.
 //--------------------------------------------------------------------------
-H5Location::H5Location( const H5Location& original ) : IdComponent( original ) {}
+// H5Location::H5Location(const H5Location& original) : IdComponent() {}
 
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
@@ -112,8 +124,9 @@ Attribute H5Location::createAttribute( const char* name, const DataType& data_ty
    // If the attribute id is valid, create and return the Attribute object
    if( attr_id > 0 )
    {
-      Attribute attr( attr_id );
-      return( attr );
+	Attribute attr;
+	f_Attribute_setId(&attr, attr_id);
+	return( attr );
    }
    else
       throw AttributeIException(inMemFunc("createAttribute"), "H5Acreate2 failed");
@@ -144,8 +157,9 @@ Attribute H5Location::openAttribute( const char* name ) const
    hid_t attr_id = H5Aopen(getId(), name, H5P_DEFAULT);
    if( attr_id > 0 )
    {
-      Attribute attr( attr_id );
-      return( attr );
+	Attribute attr;
+	f_Attribute_setId(&attr, attr_id);
+	return( attr );
    }
    else
    {
@@ -179,12 +193,13 @@ Attribute H5Location::openAttribute( const unsigned int idx ) const
 			H5_ITER_INC, (hsize_t)idx, H5P_DEFAULT, H5P_DEFAULT);
    if( attr_id > 0 )
    {
-      Attribute attr( attr_id );
-      return( attr );
+	Attribute attr;
+	f_Attribute_setId(&attr, attr_id);
+	return(attr);
    }
    else
    {
-      throw AttributeIException(inMemFunc("openAttribute"), "H5Aopen_by_idx failed");
+	throw AttributeIException(inMemFunc("openAttribute"), "H5Aopen_by_idx failed");
    }
 }
 
@@ -551,6 +566,7 @@ H5std_string H5Location::getComment(const char* name, size_t buf_size) const
 	ssize_t comment_len = getComment(name, tmp_len+1, comment_C);
 	if (comment_len < 0)
 	{
+	    delete []comment_C;
 	    throw LocationException("H5Location::getComment", "H5Oget_comment_by_name failed");
 	}
 
@@ -724,7 +740,6 @@ hid_t H5Location::p_dereference(hid_t loc_id, const void* ref, H5R_type_t ref_ty
 ///\param	loc - IN: Location of the referenced object
 ///\param	ref - IN: Reference pointer
 ///\param	ref_type - IN: Reference type
-///\param	plist - IN: Property list - default to PropList::DEFAULT
 ///\exception	H5::ReferenceException
 // Programmer	Binh-Minh Ribler - Oct, 2006
 // Modification
@@ -742,7 +757,6 @@ void H5Location::dereference(const H5Location& loc, const void* ref, H5R_type_t
 ///\param	attr - IN: Attribute specifying the location of the referenced object
 ///\param	ref - IN: Reference pointer
 ///\param	ref_type - IN: Reference type
-///\param	plist - IN: Property list - default to PropList::DEFAULT
 ///\exception	H5::ReferenceException
 // Programmer	Binh-Minh Ribler - Oct, 2006
 // Modification
@@ -882,6 +896,12 @@ H5O_type_t H5Location::p_get_ref_obj_type(void *ref, H5R_type_t ref_type) const
 ///\return	DataSpace object
 ///\exception	H5::ReferenceException
 // Programmer	Binh-Minh Ribler - May, 2004
+// Modification
+//	Mar 29, 2015
+//		Used friend function to set id for DataSpace instead of the
+//		existing id constructor or the setId method to avoid incrementing
+//		ref count, as a work-around for a problem described in the JIRA
+//		issue HDFFV-7947. -BMR
 //--------------------------------------------------------------------------
 DataSpace H5Location::getRegion(void *ref, H5R_type_t ref_type) const
 {
@@ -891,8 +911,9 @@ DataSpace H5Location::getRegion(void *ref, H5R_type_t ref_type) const
       throw ReferenceException(inMemFunc("getRegion"), "H5Rget_region failed");
    }
    try {
-      DataSpace dataspace(space_id);
-      return(dataspace);
+	DataSpace dataspace;
+	f_DataSpace_setId(&dataspace, space_id);
+	return(dataspace);
    }
    catch (DataSpaceIException E) {
       throw ReferenceException(inMemFunc("getRegion"), E.getDetailMsg());
@@ -907,6 +928,36 @@ DataSpace H5Location::getRegion(void *ref, H5R_type_t ref_type) const
 //--------------------------------------------------------------------------
 H5Location::~H5Location() {}
 
+//--------------------------------------------------------------------------
+// Function:	f_Attribute_setId - friend
+// Purpose:	This function is friend to class H5::Attribute so that it
+//		can set Attribute::id in order to work around a problem
+//		described in the JIRA issue HDFFV-7947.
+//		Applications shouldn't need to use it.
+// param	attr   - IN/OUT: Attribute object to be changed
+// param	new_id - IN: New id to set
+// Programmer	Binh-Minh Ribler - 2015
+//--------------------------------------------------------------------------
+void f_Attribute_setId(Attribute* attr, hid_t new_id)
+{
+    attr->p_setId(new_id);
+}
+
+//--------------------------------------------------------------------------
+// Function:	f_DataSpace_setId - friend
+// Purpose:	This function is friend to class H5::DataSpace so that it can
+//		can set DataSpace::id in order to work around a problem
+//		described in the JIRA issue HDFFV-7947.
+//		Applications shouldn't need to use it.
+// param	dspace   - IN/OUT: DataSpace object to be changed
+// param	new_id - IN: New id to set
+// Programmer	Binh-Minh Ribler - 2015
+//--------------------------------------------------------------------------
+void f_DataSpace_setId(DataSpace* dspace, hid_t new_id)
+{
+    dspace->p_setId(new_id);
+}
+
 #ifndef H5_NO_NAMESPACE
 } // end namespace
 #endif
