@@ -159,12 +159,9 @@ MODULE H5D_PROVISIONAL
      INTEGER FUNCTION h5dwrite_f_c(dset_id, mem_type_id, &
           mem_space_id_default ,                         &
           file_space_id_default,                         &
-          xfer_prp_default, buf )
+          xfer_prp_default, buf ) BIND(C, NAME='h5dwrite_f_c')
        USE H5GLOBAL
-       USE, INTRINSIC :: ISO_C_BINDING
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5DWRITE_F_C'::h5dwrite_f_c
-       !DEC$ENDIF
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_ptr
        INTEGER(HID_T), INTENT(IN) :: dset_id
        INTEGER(HID_T), INTENT(IN) :: mem_type_id
        INTEGER(HID_T) :: mem_space_id_default
@@ -181,12 +178,9 @@ MODULE H5D_PROVISIONAL
      INTEGER FUNCTION h5dread_f_c(dset_id, mem_type_id, &
           mem_space_id_default,                         &
           file_space_id_default,                        &
-          xfer_prp_default, buf)
+          xfer_prp_default, buf) BIND(C, NAME='h5dread_f_c')
        USE H5GLOBAL
-       USE, INTRINSIC :: ISO_C_BINDING
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5DREAD_F_C'::h5dread_f_c
-       !DEC$ENDIF
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_ptr
        INTEGER(HID_T), INTENT(IN) :: dset_id
        INTEGER(HID_T), INTENT(IN) :: mem_type_id
        INTEGER(HID_T) :: mem_space_id_default
@@ -207,12 +201,9 @@ MODULE H5D_PROVISIONAL
 
   INTERFACE
      INTEGER FUNCTION h5dfill_c(f_ptr_fill_value, fill_type_id, space_id, &
-          f_ptr_buf, mem_type_id)
+          f_ptr_buf, mem_type_id) BIND(C, NAME='h5dfill_c')
        USE H5GLOBAL
-       USE, INTRINSIC :: ISO_C_BINDING
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5DFILL_C'::h5dfill_c
-       !DEC$ENDIF
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_ptr
        TYPE(C_PTR), VALUE :: f_ptr_fill_value
        INTEGER(HID_T) :: fill_type_id ! Fill value datatype identifier
        INTEGER(HID_T), INTENT(IN) :: space_id ! Memory dataspace selection identifier
@@ -2369,7 +2360,7 @@ CONTAINS
 !
 ! Fortran2003 Interface:
   SUBROUTINE h5dvlen_reclaim_f(type_id, space_id, plist_id, buf, hdferr)
-    USE, INTRINSIC :: ISO_C_BINDING
+    USE, INTRINSIC :: ISO_C_BINDING, ONLY : C_PTR
     IMPLICIT NONE
     INTEGER(HID_T), INTENT(IN)    :: type_id
     INTEGER(HID_T), INTENT(IN)    :: space_id
@@ -2379,12 +2370,9 @@ CONTAINS
 !*****
 
     INTERFACE
-       INTEGER FUNCTION h5dvlen_reclaim_c(type_id, space_id, plist_id, buf)
+       INTEGER FUNCTION h5dvlen_reclaim_c(type_id, space_id, plist_id, buf) BIND(C, NAME='h5dvlen_reclaim_c')
          USE H5GLOBAL
-         USE, INTRINSIC :: ISO_C_BINDING
-         !DEC$IF DEFINED(HDF5F90_WINDOWS)
-         !DEC$ATTRIBUTES C,reference,decorate,alias:'H5DVLEN_RECLAIM_C'::h5dvlen_reclaim_c
-         !DEC$ENDIF
+         USE, INTRINSIC :: ISO_C_BINDING, ONLY : C_PTR
          INTEGER(HID_T) :: type_id
          INTEGER(HID_T) :: space_id
          INTEGER(HID_T) :: plist_id
