@@ -26,9 +26,9 @@
 
 /****if* H5Tf/h5topen_c
  * NAME
- *        h5topen_c
+ *  h5topen_c
  * PURPOSE
- *     Call H5Topen2 to open a datatype
+ *  Call H5Topen2 to open a datatype
  * INPUTS
  *      loc_id - file or group identifier
  *              name - name of the datatype within file or  group
@@ -78,9 +78,9 @@ done:
 
 /****if* H5Tf/h5tcommit_c
  * NAME
- *        h5tcommit_c
+ *  h5tcommit_c
  * PURPOSE
- *     Call H5Tcommit2 to commit a datatype
+ *  Call H5Tcommit2 to commit a datatype
  * INPUTS
  *      loc_id - file or group identifier
  *              name - name of the datatype within file or  group
@@ -126,9 +126,9 @@ done:
 
 /****if* H5Tf/h5tclose_c
  * NAME
- *        h5tclose_c
+ *  h5tclose_c
  * PURPOSE
- *     Call H5Tclose to close the datatype
+ *  Call H5Tclose to close the datatype
  * INPUTS
  *      type_id - identifier of the datatype to be closed
  * RETURNS
@@ -156,9 +156,9 @@ nh5tclose_c ( hid_t_f *type_id )
 
 /****if* H5Tf/h5tcopy_c
  * NAME
- *        h5tcopy_c
+ *  h5tcopy_c
  * PURPOSE
- *     Call H5Tcopy to copy a datatype
+ *  Call H5Tcopy to copy a datatype
  * INPUTS
  *      type_id - identifier of the datatype to be copied
  * OUTPUTS
@@ -190,9 +190,9 @@ nh5tcopy_c ( hid_t_f *type_id , hid_t_f *new_type_id)
 
 /****if* H5Tf/h5tequal_c
  * NAME
- *        h5tequal_c
+ *  h5tequal_c
  * PURPOSE
- *     Call H5Tequal to copy a datatype
+ *  Call H5Tequal to copy a datatype
  * INPUTS
  *      type1_id - datatype identifier
  *              type2_id - datatype identifier
@@ -225,31 +225,32 @@ nh5tequal_c ( hid_t_f *type1_id , hid_t_f *type2_id, int_f *c_flag)
   return ret_value;
 }
 
-
 /****if* H5Tf/h5tget_class_c
  * NAME
- *        h5tget_class_c
+ *  h5tget_class_c
  * PURPOSE
- *     Call H5Tget_class to determine the datatype class
+ *  Call H5Tget_class to determine the datatype class
  * INPUTS
- *      type_id - identifier of the dataspace
+ *  type_id - identifier of the dataspace
  * OUTPUTS
- *     classtype - class type; possible values are:
- *              H5T_NO_CLASS_F (-1)
- *              H5T_INTEGER_F (0)
- *              H5T_FLOAT_F (1)
- *              H5T_TIME_F (2)
- *              H5T_STRING_F (3)
- *              H5T_BITFIELD_F (4)
- *              H5T_OPAQUE_F (5)
- *              H5T_COMPOUNDF (6)
- *              H5T_REFERENCE_F (7)
- *              H5T_ENUMF (8)
+ *  classtype - class type; possible values are:
+ *               H5T_NO_CLASS_F (-1)
+ *               H5T_INTEGER_F (0)
+ *               H5T_FLOAT_F (1)
+ *               H5T_TIME_F (2)
+ *               H5T_STRING_F (3)
+ *               H5T_BITFIELD_F (4)
+ *               H5T_OPAQUE_F (5)
+ *               H5T_COMPOUNDF (6)
+ *               H5T_REFERENCE_F (7)
+ *               H5T_ENUM_F (8)
+ *               H5T_VLEN_F (9)
+ *               H5T_ARRAY_F (10)
  * RETURNS
- *     0 on success, -1 on failure
+ *  0 on success, -1 on failure
  * AUTHOR
  *  Elena Pourmal
- *              Saturday, August 14, 1999
+ *  Saturday, August 14, 1999
  * HISTORY
  *
  * SOURCE
@@ -288,9 +289,9 @@ nh5tget_class_c ( hid_t_f *type_id , int_f *classtype)
 
 /****if* H5Tf/h5tget_order_c
  * NAME
- *        h5tget_order_c
+ *  h5tget_order_c
  * PURPOSE
- *     Call H5Tget_order to determine byte order
+ *  Call H5Tget_order to determine byte order
  * INPUTS
  *      type_id - identifier of the dataspace
  * OUTPUTS
@@ -332,9 +333,9 @@ nh5tget_order_c ( hid_t_f *type_id , int_f *order)
 
 /****if* H5Tf/h5tset_order_c
  * NAME
- *        h5tset_order_c
+ *  h5tset_order_c
  * PURPOSE
- *     Call H5Tset_order to set byte order
+ *  Call H5Tset_order to set byte order
  * INPUTS
  *      type_id - identifier of the dataspace
  *              order; possible values are:
@@ -373,9 +374,9 @@ nh5tset_order_c ( hid_t_f *type_id , int_f *order)
 
 /****if* H5Tf/h5tget_size_c
  * NAME
- *        h5tget_size_c
+ *  h5tget_size_c
  * PURPOSE
- *     Call H5Tget_size to get size of the datatype
+ *  Call H5Tget_size to get size of the datatype
  * INPUTS
  *      type_id - identifier of the dataspace
  * OUTPUTS
@@ -408,9 +409,9 @@ nh5tget_size_c ( hid_t_f *type_id , size_t_f *size)
 
 /****if* H5Tf/h5tset_size_c
  * NAME
- *        h5tset_size_c
+ *  h5tset_size_c
  * PURPOSE
- *     Call H5Tget_size to get size of the datatype
+ *  Call H5Tget_size to get size of the datatype
  * INPUTS
  *      type_id - identifier of the dataspace
  * OUTPUTS
@@ -444,9 +445,9 @@ nh5tset_size_c ( hid_t_f *type_id , size_t_f *size)
 
 /****if* H5Tf/h5tget_precision_c
  * NAME
- *        h5tget_precision_c
+ *  h5tget_precision_c
  * PURPOSE
- *     Call H5Tget_precision to get precision of the datatype
+ *  Call H5Tget_precision to get precision of the datatype
  * INPUTS
  *      type_id - identifier of the dataspace
  * OUTPUTS
@@ -479,9 +480,9 @@ nh5tget_precision_c ( hid_t_f *type_id , size_t_f *precision)
 
 /****if* H5Tf/h5tset_precision_c
  * NAME
- *        h5tset_precision_c
+ *  h5tset_precision_c
  * PURPOSE
- *     Call H5Tset_precision to set precision of the datatype
+ *  Call H5Tset_precision to set precision of the datatype
  * INPUTS
  *      type_id - identifier of the dataspace
  *              precision -  number of significant bits
@@ -514,9 +515,9 @@ nh5tset_precision_c ( hid_t_f *type_id , size_t_f *precision)
 
 /****if* H5Tf/h5tget_offset_c
  * NAME
- *        h5tget_offset_c
+ *  h5tget_offset_c
  * PURPOSE
- *     Call H5Tget_offset to get bit offset of the first
+ *  Call H5Tget_offset to get bit offset of the first
  *              significant bit of the datatype
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -551,9 +552,9 @@ nh5tget_offset_c ( hid_t_f *type_id , size_t_f *offset)
 
 /****if* H5Tf/h5tset_offset_c
  * NAME
- *        h5tset_offset_c
+ *  h5tset_offset_c
  * PURPOSE
- *     Call H5Tset_offset to set bit offset of the first
+ *  Call H5Tset_offset to set bit offset of the first
  *              significant bit of the datatype
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -587,9 +588,9 @@ nh5tset_offset_c ( hid_t_f *type_id , size_t_f *offset)
 
 /****if* H5Tf/h5tget_pad_c
  * NAME
- *        h5tget_pad_c
+ *  h5tget_pad_c
  * PURPOSE
- *     Call H5Tget_pad to get the padding type of the least and
+ *  Call H5Tget_pad to get the padding type of the least and
  *              most-significant bit padding
  *
  * INPUTS
@@ -628,11 +629,11 @@ nh5tget_pad_c ( hid_t_f *type_id , int_f * lsbpad, int_f * msbpad)
 
 /****if* H5Tf/h5tset_pad_c
  * NAME
- *        h5tset_pad_c
+ *  h5tset_pad_c
  * INPUTS
  *      type_id - identifier of the dataspace
  * PURPOSE
- *     Call H5Tset_pad to set the padding type of the least and
+ *  Call H5Tset_pad to set the padding type of the least and
  *              most-significant bit padding
  *
  * INPUTS
@@ -669,9 +670,9 @@ nh5tset_pad_c ( hid_t_f *type_id, int_f * lsbpad, int_f* msbpad )
 
 /****if* H5Tf/h5tget_sign_c
  * NAME
- *        h5tget_sign_c
+ *  h5tget_sign_c
  * PURPOSE
- *     Call H5Tget_sign to get sign type for an integer type
+ *  Call H5Tget_sign to get sign type for an integer type
  * INPUTS
  *      type_id - identifier of the dataspace
  * OUTPUTS
@@ -704,9 +705,9 @@ nh5tget_sign_c ( hid_t_f *type_id , int_f *sign)
 
 /****if* H5Tf/h5tset_sign_c
  * NAME
- *        h5tset_sign_c
+ *  h5tset_sign_c
  * PURPOSE
- *     Call H5Tset_sign to set sign type for an integer type
+ *  Call H5Tset_sign to set sign type for an integer type
  * INPUTS
  *      type_id - identifier of the dataspace
  *              sign - sign type for an integer typ
@@ -740,9 +741,9 @@ nh5tset_sign_c ( hid_t_f *type_id , int_f* sign)
 
 /****if* H5Tf/h5tget_fields_c
  * NAME
- *        h5tget_fields_c
+ *  h5tget_fields_c
  * PURPOSE
- *     Call H5Tget_fields to get floating point datatype
+ *  Call H5Tget_fields to get floating point datatype
  *              bit field information
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -784,9 +785,9 @@ nh5tget_fields_c ( hid_t_f *type_id , size_t_f *spos, size_t_f *epos, size_t_f*
 
 /****if* H5Tf/h5tset_fields_c
  * NAME
- *        h5tset_fields_c
+ *  h5tset_fields_c
  * PURPOSE
- *     Call H5Tset_fields to set floating point datatype
+ *  Call H5Tset_fields to set floating point datatype
  *              bit field information
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -828,9 +829,9 @@ nh5tset_fields_c ( hid_t_f *type_id, size_t_f *spos, size_t_f *epos, size_t_f* e
 
 /****if* H5Tf/h5tget_ebias_c
  * NAME
- *        h5tget_ebias_c
+ *  h5tget_ebias_c
  * PURPOSE
- *     Call H5Tget_ebias to get  exponent bias of a
+ *  Call H5Tget_ebias to get  exponent bias of a
  *              floating-point type of the datatype
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -865,9 +866,9 @@ nh5tget_ebias_c ( hid_t_f *type_id , size_t_f *ebias)
 
 /****if* H5Tf/h5tset_ebias_c
  * NAME
- *        h5tset_ebias_c
+ *  h5tset_ebias_c
  * PURPOSE
- *     Call H5Tset_ebias to set exponent bias of a
+ *  Call H5Tset_ebias to set exponent bias of a
  *              floating-point type of the datatype
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -902,9 +903,9 @@ nh5tset_ebias_c ( hid_t_f *type_id , size_t_f *ebias)
 
 /****if* H5Tf/h5tget_norm_c
  * NAME
- *        h5tget_norm_c
+ *  h5tget_norm_c
  * PURPOSE
- *     Call H5Tget_norm to get mantissa normalization
+ *  Call H5Tget_norm to get mantissa normalization
  *              of a floating-point datatype
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -939,9 +940,9 @@ nh5tget_norm_c ( hid_t_f *type_id , int_f *norm)
 
 /****if* H5Tf/h5tset_norm_c
  * NAME
- *        h5tset_norm_c
+ *  h5tset_norm_c
  * PURPOSE
- *     Call H5Tset_norm to set mantissa normalization of
+ *  Call H5Tset_norm to set mantissa normalization of
  *              floating-point type of the datatype
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -976,9 +977,9 @@ nh5tset_norm_c ( hid_t_f *type_id , int_f *norm)
 
 /****if* H5Tf/h5tget_inpad_c
  * NAME
- *        h5tget_inpad_c
+ *  h5tget_inpad_c
  * PURPOSE
- *     Call H5Tget_inpad to get the padding type for
+ *  Call H5Tget_inpad to get the padding type for
  *              unused bits in floating-point datatypes
  *
  * INPUTS
@@ -1015,11 +1016,11 @@ nh5tget_inpad_c ( hid_t_f *type_id , int_f * padtype)
 
 /****if* H5Tf/h5tset_inpad_c
  * NAME
- *        h5tset_inpad_c
+ *  h5tset_inpad_c
  * INPUTS
  *      type_id - identifier of the dataspace
  * PURPOSE
- *     Call H5Tset_inpad to set the padding type
+ *  Call H5Tset_inpad to set the padding type
  *              unused bits in floating-point datatype
  *
  * INPUTS
@@ -1056,9 +1057,9 @@ nh5tset_inpad_c ( hid_t_f *type_id, int_f * padtype)
 
 /****if* H5Tf/h5tget_cset_c
  * NAME
- *        h5tget_cset_c
+ *  h5tget_cset_c
  * PURPOSE
- *     Call H5Tget_cset to get character set
+ *  Call H5Tget_cset to get character set
  *              type of a string datatype
  *
  * INPUTS
@@ -1094,11 +1095,11 @@ nh5tget_cset_c ( hid_t_f *type_id , int_f * cset)
 
 /****if* H5Tf/h5tset_cset_c
  * NAME
- *        h5tset_cset_c
+ *  h5tset_cset_c
  * INPUTS
  *      type_id - identifier of the dataspace
  * PURPOSE
- *     Call H5Tset_cset to set character set
+ *  Call H5Tset_cset to set character set
  *              type of a string datatype
  *
  * INPUTS
@@ -1134,9 +1135,9 @@ nh5tset_cset_c ( hid_t_f *type_id, int_f * cset)
 
 /****if* H5Tf/h5tget_strpad_c
  * NAME
- *        h5tget_strpad_c
+ *  h5tget_strpad_c
  * PURPOSE
- *     Call H5Tget_strpad to get string padding method
+ *  Call H5Tget_strpad to get string padding method
  *              for a string datatype
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -1170,11 +1171,11 @@ nh5tget_strpad_c ( hid_t_f *type_id , int_f * strpad)
 
 /****if* H5Tf/h5tset_strpad_c
  * NAME
- *        h5tset_strpad_c
+ *  h5tset_strpad_c
  * INPUTS
  *      type_id - identifier of the dataspace
  * PURPOSE
- *     Call H5Tset_strpad to set string padding method
+ *  Call H5Tset_strpad to set string padding method
  *              for a string datatype
  *
  * INPUTS
@@ -1210,9 +1211,9 @@ nh5tset_strpad_c ( hid_t_f *type_id, int_f * strpad)
 
 /****if* H5Tf/h5tget_nmembers_c
  * NAME
- *        h5tget_nmembers_c
+ *  h5tget_nmembers_c
  * PURPOSE
- *     Call H5Tget_nmembers to get number of fields
+ *  Call H5Tget_nmembers to get number of fields
  *              in a compound datatype
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -1245,9 +1246,9 @@ nh5tget_nmembers_c ( hid_t_f *type_id , int_f * num_members)
 
 /****if* H5Tf/h5tget_member_name_c
  * NAME
- *        h5tget_member_name_c
+ *  h5tget_member_name_c
  * PURPOSE
- *     Call H5Tget_member_name to get name
+ *  Call H5Tget_member_name to get name
  *              of a compound datatype
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -1280,15 +1281,15 @@ nh5tget_member_name_c ( hid_t_f *type_id ,int_f* idx, _fcd member_name, int_f *n
 
   HD5packFstring(c_name, _fcdtocp(member_name), strlen(c_name));
   *namelen = (int_f)strlen(c_name);
-  HDfree(c_name);
+  H5free_memory(c_name);
   ret_value = 0;
   return ret_value;
 }
 /****if* H5Tf/h5tget_member_index_c
  * NAME
- *        h5tget_member_index_c
+ *  h5tget_member_index_c
  * PURPOSE
- *     Call H5Tget_member_index to get an index of
+ *  Call H5Tget_member_index to get an index of
  *              the specified datatype filed or member.
  * INPUTS
  *      type_id - datatype identifier
@@ -1300,7 +1301,7 @@ nh5tget_member_name_c ( hid_t_f *type_id ,int_f* idx, _fcd member_name, int_f *n
  *     0 on success, -1 on failure
  * AUTHOR
  *  Elena Pourmal
- *              Thursday, September 26, 2002
+ *  Thursday, September 26, 2002
  * HISTORY
  *
  * SOURCE
@@ -1311,15 +1312,13 @@ nh5tget_member_index_c (hid_t_f *type_id, _fcd name, int_f *namelen, int_f *idx)
 {
      int ret_value = -1;
      char *c_name;
-     size_t c_namelen;
      hid_t c_type_id;
      int c_index;
 
      /*
       * Convert FORTRAN name to C name
       */
-     c_namelen = *namelen;
-     c_name = (char *)HD5f2cstring(name, c_namelen);
+     c_name = (char *)HD5f2cstring(name, (size_t)*namelen);
      if (c_name == NULL) return ret_value;
 
      /*
@@ -1339,9 +1338,9 @@ DONE:
 
 /****if* H5Tf/h5tget_member_offset_c
  * NAME
- *        h5tget_member_offset_c
+ *  h5tget_member_offset_c
  * PURPOSE
- *     Call H5Tget_member_offset to get byte offset of the
+ *  Call H5Tget_member_offset to get byte offset of the
  *              beginning of a field within a compound datatype with
  *              respect to the beginning of the compound data type datum
  * INPUTS
@@ -1366,12 +1365,8 @@ nh5tget_member_offset_c ( hid_t_f *type_id ,int_f* member_no, size_t_f * offset)
 {
   int ret_value = -1;
   size_t c_offset;
-  hid_t c_type_id;
-  unsigned c_member_no;
 
-  c_type_id = *type_id;
-  c_member_no = *member_no;
-  c_offset = H5Tget_member_offset(c_type_id, c_member_no);
+  c_offset = H5Tget_member_offset((hid_t)*type_id, (unsigned)*member_no);
   *offset = (size_t_f)c_offset;
   ret_value = 0;
   return ret_value;
@@ -1379,9 +1374,9 @@ nh5tget_member_offset_c ( hid_t_f *type_id ,int_f* member_no, size_t_f * offset)
 
 /****if* H5Tf/h5tget_array_dims_c
  * NAME
- *        h5tget_array_dims_c
+ *  h5tget_array_dims_c
  * PURPOSE
- *     Call H5Tget_array_dims2 to get
+ *  Call H5Tget_array_dims2 to get
  *              dimensions of array datatype
  * INPUTS
  *      type_id - identifier of the array datatype
@@ -1422,9 +1417,9 @@ DONE:
 
 /****if* H5Tf/h5tget_array_ndims_c
  * NAME
- *        h5tget_array_ndims_c
+ *  h5tget_array_ndims_c
  * PURPOSE
- *     Call H5Tget_array_ndims to get number
+ *  Call H5Tget_array_ndims to get number
  *              of dimensions of array datatype
  * INPUTS
  *      type_id - identifier of the array datatype
@@ -1459,9 +1454,9 @@ nh5tget_array_ndims_c ( hid_t_f *type_id , int_f * ndims)
 
 /****if* H5Tf/h5tget_super_c
  * NAME
- *        h5tget_super_c
+ *  h5tget_super_c
  * PURPOSE
- *     Call H5Tget_super to get base datatype from which
+ *  Call H5Tget_super to get base datatype from which
  *              datatype was derived
  * INPUTS
  *      type_id - identifier of the array datatype
@@ -1497,9 +1492,9 @@ nh5tget_super_c ( hid_t_f *type_id , hid_t_f *base_type_id)
 
 /****if* H5Tf/h5tget_member_type_c
  * NAME
- *        h5tget_member_type_c
+ *  h5tget_member_type_c
  * PURPOSE
- *     Call H5Tget_member_type to get the identifier of a copy of
+ *  Call H5Tget_member_type to get the identifier of a copy of
  *              the datatype of the field
  * INPUTS
  *      type_id - identifier of the datatype
@@ -1510,7 +1505,7 @@ nh5tget_super_c ( hid_t_f *type_id , hid_t_f *base_type_id)
  *     0 on success, -1 on failure
  * AUTHOR
  *  XIANGYANG SU
- *              Thursday, February 3, 2000
+ *  Thursday, February 3, 2000
  * HISTORY
  *
  * SOURCE
@@ -1521,12 +1516,8 @@ nh5tget_member_type_c ( hid_t_f *type_id ,int_f* field_idx, hid_t_f * datatype)
 /******/
 {
   int ret_value = -1;
-  hid_t c_type_id;
-  unsigned c_field_idx;
 
-  c_type_id = *type_id;
-  c_field_idx = *field_idx;
-  *datatype = (hid_t_f)H5Tget_member_type(c_type_id, c_field_idx);
+  *datatype = (hid_t_f)H5Tget_member_type((hid_t)*type_id, (unsigned)*field_idx);
   if(*datatype < 0) return ret_value;
 
   ret_value = 0;
@@ -1536,9 +1527,9 @@ nh5tget_member_type_c ( hid_t_f *type_id ,int_f* field_idx, hid_t_f * datatype)
 
 /****if* H5Tf/h5tcreate_c
  * NAME
- *        h5tcreate_c
+ *  h5tcreate_c
  * PURPOSE
- *     Call H5Tcreate to create a datatype
+ *  Call H5Tcreate to create a datatype
  * INPUTS
  *      cls - class type
  *     size - size of the class memeber
@@ -1572,20 +1563,20 @@ nh5tcreate_c(int_f *cls, size_t_f *size, hid_t_f *type_id)
 
 /****if* H5Tf/h5tinsert_c
  * NAME
- *        h5tinsert_c
+ *  h5tinsert_c
  * PURPOSE
- *     Call H5Tinsert to adds another member to the compound datatype
+ *  Call H5Tinsert to adds another member to the compound datatype
  * INPUTS
- *      type_id - identifier of the datatype
- *              name  - Name of the field to insert
- *              namelen - length of the name
- *              offset - Offset in memory structure of the field to insert
- *              field_id - datatype identifier of the new member
+ *  type_id  - identifier of the datatype
+ *  name     - Name of the field to insert
+ *  namelen - length of the name
+ *  offset   - Offset in memory structure of the field to insert
+ *  field_id - datatype identifier of the new member
  * RETURNS
- *     0 on success, -1 on failure
+ *  0 on success, -1 on failure
  * AUTHOR
  *  XIANGYANG SU
- *              Thursday, February 3, 2000
+ *  Thursday, February 3, 2000
  * HISTORY
  *
  * SOURCE
@@ -1596,21 +1587,14 @@ nh5tinsert_c(hid_t_f *type_id, _fcd name, int_f* namelen, size_t_f *offset, hid_
 /******/
 {
   int ret_value = -1;
-  hid_t c_type_id;
-  hid_t c_field_id;
   char* c_name;
-  size_t c_namelen;
-  size_t c_offset;
   herr_t error;
 
-  c_offset =(size_t) *offset;
-  c_namelen = *namelen;
-  c_name = (char *)HD5f2cstring(name, c_namelen);
+  c_name = (char *)HD5f2cstring(name, (size_t)*namelen);
   if (c_name == NULL) return ret_value;
 
-  c_type_id = *type_id;
-  c_field_id = *field_id;
-  error = H5Tinsert(c_type_id, c_name, c_offset, c_field_id);
+  error = H5Tinsert((hid_t)*type_id, c_name, (size_t)*offset, (hid_t)*field_id);
+
   HDfree(c_name);
   if(error < 0) return ret_value;
   ret_value = 0;
@@ -1620,18 +1604,18 @@ nh5tinsert_c(hid_t_f *type_id, _fcd name, int_f* namelen, size_t_f *offset, hid_
 
 /****if* H5Tf/h5tpack_c
  * NAME
- *        h5tpack_c
+ *  h5tpack_c
  * PURPOSE
- *     Call H5Tpack tor ecursively remove padding from
- *              within a compound datatype to make it more efficient
- *              (space-wise) to store that data
+ *  Call H5Tpack tor ecursively remove padding from
+ *  within a compound datatype to make it more efficient
+ *  (space-wise) to store that data
  * INPUTS
- *      type_id - identifier of the datatype
+ *  type_id - identifier of the datatype
  * RETURNS
- *     0 on success, -1 on failure
+ *  0 on success, -1 on failure
  * AUTHOR
  *  XIANGYANG SU
- *              Thursday, February 3, 2000
+ *  Thursday, February 3, 2000
  * HISTORY
  *
  * SOURCE
@@ -1655,9 +1639,9 @@ nh5tpack_c(hid_t_f * type_id)
 
 /****if* H5Tf/h5tarray_create_c
  * NAME
- *        h5tarray_create_c
+ *  h5tarray_create_c
  * PURPOSE
- *     Call H5Tarray_create2 to create array datatype
+ *  Call H5Tarray_create2 to create array datatype
  * INPUTS
  *      base_id - identifier of array base datatype
  *              rank - array's rank
@@ -1667,7 +1651,7 @@ nh5tpack_c(hid_t_f * type_id)
  *     0 on success, -1 on failure
  * AUTHOR
  *  Elena Pourmal
- *              Thursday, November 16, 2000
+ *  Thursday, November 16, 2000
  * HISTORY
  *
  * SOURCE
@@ -1686,7 +1670,7 @@ nh5tarray_create_c(hid_t_f * base_id, int_f *rank, hsize_t_f* dims, hid_t_f* typ
      * Transpose dimension arrays because of C-FORTRAN storage order
      */
     for(u = 0; u < (unsigned)*rank ; u++)
-        c_dims[u] =  (hsize_t)dims[(*rank - u) - 1];
+      c_dims[u] =  (hsize_t)dims[((unsigned)*rank - u) - 1];
 
     if((c_type_id = H5Tarray_create2((hid_t)*base_id, (unsigned)*rank, c_dims)) < 0)
         goto DONE;
@@ -1701,19 +1685,19 @@ DONE:
 
 /****if* H5Tf/h5tenum_create_c
  * NAME
- *        h5tenum_create_c
+ *  h5tenum_create_c
  * PURPOSE
- *     Call H5Tenum_create to create a new enumeration datatype
+ *  Call H5Tenum_create to create a new enumeration datatype
  * INPUTS
- *      parent_id - Datatype identifier for the base datatype
+ *  parent_id - Datatype identifier for the base datatype
  * OUTPUTS
- *     new_type_id - datatype identifier for the new
- *                            enumeration datatype
+ *  new_type_id - datatype identifier for the new
+ *                enumeration datatype
  * RETURNS
- *     0 on success, -1 on failure
+ *  0 on success, -1 on failure
  * AUTHOR
  *  Xiangyang Su
- *              Tuesday, February 15, 1999
+ *  Tuesday, February 15, 1999
  * HISTORY
  *
  * SOURCE
@@ -1724,11 +1708,9 @@ nh5tenum_create_c ( hid_t_f *parent_id , hid_t_f *new_type_id)
 /******/
 {
   int ret_value = 0;
-  hid_t c_parent_id;
   hid_t c_new_type_id;
 
-  c_parent_id = *parent_id;
-  c_new_type_id = H5Tenum_create(c_parent_id);
+  c_new_type_id = H5Tenum_create((hid_t)*parent_id);
   if ( c_new_type_id < 0  ) ret_value = -1;
 
   *new_type_id = (hid_t_f)c_new_type_id;
@@ -1737,21 +1719,23 @@ nh5tenum_create_c ( hid_t_f *parent_id , hid_t_f *new_type_id)
 
 /****if* H5Tf/h5tenum_insert_c
  * NAME
- *        h5tenum_insert_c
+ *  h5tenum_insert_c
  * PURPOSE
- *     Call H5Tenum_insert to insert a new enumeration datatype member.
+ *  Call H5Tenum_insert to insert a new enumeration datatype member.
  * INPUTS
- *      type_id - identifier of the datatype
- *              name  - Name of  the new member
- *              namelen - length of the name
- *              value - value of the new member
+ *  type_id - identifier of the datatype
+ *  name    - Name of  the new member
+ *  namelen - length of the name
+ *  value   - value of the new member
  * RETURNS
- *     0 on success, -1 on failure
+ *  0 on success, -1 on failure
  * AUTHOR
  *  XIANGYANG SU
- *              Thursday, February 3, 2000
+ *  Thursday, February 3, 2000
  * HISTORY
- *
+ *  'value' is no longer cast into an int. If the user passes in an 8 byte integer then
+ *  it should not be cast to an int (which might be 4 bytes). Instead the value
+ *  is written as the size of an int_f.
  * SOURCE
 */
 
@@ -1760,19 +1744,16 @@ nh5tenum_insert_c(hid_t_f *type_id, _fcd name, int_f* namelen, int_f* value)
 /******/
 {
   int ret_value = -1;
-  hid_t c_type_id;
   char* c_name;
-  size_t c_namelen;
-  int_f c_value;
   herr_t error;
+  int_f c_value;
 
-  c_namelen = *namelen;
-  c_name = (char *)HD5f2cstring(name, c_namelen);
+  c_name = (char *)HD5f2cstring(name, (size_t)*namelen);
   if (c_name == NULL) return ret_value;
 
-  c_type_id = (hid_t)*type_id;
-  c_value = (int)*value;
-  error = H5Tenum_insert(c_type_id, c_name, &c_value);
+  c_value = *value;
+  error = H5Tenum_insert((hid_t)*type_id, c_name, &c_value);
+
   HDfree(c_name);
   if(error < 0) return ret_value;
 
@@ -1783,9 +1764,9 @@ nh5tenum_insert_c(hid_t_f *type_id, _fcd name, int_f* namelen, int_f* value)
 
 /****if* H5Tf/h5tenum_nameof_c
  * NAME
- *        h5tenum_nameof_c
+ *  h5tenum_nameof_c
  * PURPOSE
- *     Call H5Tenum_nameof to find the symbol name that corresponds to
+ *  Call H5Tenum_nameof to find the symbol name that corresponds to
  *              the specified value of the enumeration datatype type
  * INPUTS
  *      type_id - identifier of the datatype
@@ -1827,9 +1808,9 @@ nh5tenum_nameof_c(hid_t_f *type_id, int_f* value, _fcd name, size_t_f* namelen)
 
 /****if* H5Tf/h5tenum_valueof_c
  * NAME
- *        h5tenum_valueof_c
+ *  h5tenum_valueof_c
  * PURPOSE
- *     Call H5Tenum_valueof to find the value of that corresponds to
+ *  Call H5Tenum_valueof to find the value of that corresponds to
  *              the specified name of the enumeration datatype type
  * INPUTS
  *      type_id - identifier of the datatype
@@ -1851,16 +1832,12 @@ nh5tenum_valueof_c(hid_t_f *type_id, _fcd name, int_f* namelen, int_f* value)
 /******/
 {
   int ret_value = -1;
-  hid_t c_type_id;
   char* c_name;
-  size_t c_namelen;
   herr_t error;
-  c_namelen = *namelen;
-  c_name = (char *)HD5f2cstring(name, c_namelen);
+  c_name = (char *)HD5f2cstring(name, (size_t)*namelen);
   if (c_name == NULL) return ret_value;
 
-  c_type_id = *type_id;
-  error = H5Tenum_valueof(c_type_id, c_name, value);
+  error = H5Tenum_valueof((hid_t)*type_id, c_name, value);
   HDfree(c_name);
 
   if(error < 0) return ret_value;
@@ -1871,9 +1848,9 @@ nh5tenum_valueof_c(hid_t_f *type_id, _fcd name, int_f* namelen, int_f* value)
 
 /****if* H5Tf/h5tget_member_value_c
  * NAME
- *        h5tget_member_value_c
+ *  h5tget_member_value_c
  * PURPOSE
- *     Call H5Tget_member_value to get the value of an
+ *  Call H5Tget_member_value to get the value of an
  *              enumeration datatype member
  * INPUTS
  *      type_id - identifier of the datatype
@@ -1894,14 +1871,10 @@ nh5tget_member_value_c(hid_t_f *type_id, int_f* member_no, int_f* value)
 /******/
 {
   int ret_value = -1;
-  hid_t c_type_id;
-  unsigned c_member_no;
   int c_value;
   herr_t error;
 
-  c_type_id = *type_id;
-  c_member_no = *member_no;
-  error = H5Tget_member_value(c_type_id, c_member_no, &c_value);
+  error = H5Tget_member_value((hid_t)*type_id, (unsigned)*member_no, &c_value);
   if(error < 0) return ret_value;
 
   *value = (int_f)c_value;
@@ -1911,11 +1884,11 @@ nh5tget_member_value_c(hid_t_f *type_id, int_f* member_no, int_f* value)
 
 /****if* H5Tf/h5tset_tag_c
  * NAME
- *        h5tset_tag_c
+ *  h5tset_tag_c
  * INPUTS
  *      type_id - identifier of the dataspace
  * PURPOSE
- *     Call H5Tset_tag to set an opaque datatype tag
+ *  Call H5Tset_tag to set an opaque datatype tag
  * INPUTS
  *      type_id - identifier of the dataspace
  *              tag -  Unique ASCII string with which the opaque
@@ -1935,16 +1908,12 @@ nh5tset_tag_c(hid_t_f* type_id, _fcd tag, int_f* namelen)
 /******/
 {
   int ret_value = -1;
-  hid_t c_type_id;
   herr_t status;
   char* c_tag;
-  size_t c_namelen;
 
-  c_namelen = *namelen;
-  c_tag = (char *)HD5f2cstring(tag, c_namelen);
+  c_tag = (char *)HD5f2cstring(tag, (size_t)*namelen);
 
-  c_type_id = *type_id;
-  status = H5Tset_tag(c_type_id, c_tag);
+  status = H5Tset_tag((hid_t)*type_id, c_tag);
   HDfree(c_tag);
   if ( status < 0 ) return ret_value;
 
@@ -1954,7 +1923,7 @@ nh5tset_tag_c(hid_t_f* type_id, _fcd tag, int_f* namelen)
 
 /****if* H5Tf/h5tget_tag_c
  * NAME
- *        h5tget_tag_c
+ *  h5tget_tag_c
  * PURPOSE
  *  Call H5Tset_tag to set an opaque datatype tag
  * INPUTS
@@ -1986,15 +1955,15 @@ nh5tget_tag_c(hid_t_f* type_id, _fcd tag, size_t_f* tag_size, int_f* taglen)
 
   HD5packFstring(c_tag, _fcdtocp(tag), (size_t)*tag_size);
   *taglen = (int_f)HDstrlen(c_tag);
-  HDfree(c_tag);
+  H5free_memory(c_tag);
   ret_value = 0;
   return ret_value;
 }
 /****if* H5Tf/h5tvlen_create_c
  * NAME
- *        h5tvlen_create_c
+ *  h5tvlen_create_c
  * PURPOSE
- *     Call H5Tvlen_create to create VL dtatype
+ *  Call H5Tvlen_create to create VL dtatype
  * INPUTS
  *      type_id - identifier of the base datatype
  * OUTPUTS
@@ -2025,9 +1994,9 @@ nh5tvlen_create_c(hid_t_f* type_id, hid_t_f *vltype_id)
 }
 /****if* H5Tf/h5tis_variable_str_c
  * NAME
- *        h5tis_variable_str_c
+ *  h5tis_variable_str_c
  * PURPOSE
- *     Call H5Tis_variable_str to detrmine if the datatype
+ *  Call H5Tis_variable_str to detrmine if the datatype
  *              is a variable string.
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -2060,9 +2029,9 @@ nh5tis_variable_str_c ( hid_t_f *type_id , int_f *flag )
 }
 /****if* H5Tf/h5tget_member_class_c
  * NAME
- *        h5tget_member_class_c
+ *  h5tget_member_class_c
  * PURPOSE
- *     Call H5Tget_member_class to detrmine ithe class of the compound
+ *  Call H5Tget_member_class to detrmine ithe class of the compound
  *		datatype member
  * INPUTS
  *      type_id - identifier of the dataspace
@@ -2100,9 +2069,9 @@ nh5tget_member_class_c ( hid_t_f *type_id ,  int_f *member_no, int_f *cls )
 
 /****if* H5Tf/h5tcommit_anon_c
  * NAME
- *        h5tcommit_anon_c
+ *  h5tcommit_anon_c
  * PURPOSE
- *     Call H5Tcommit_anon
+ *  Call H5Tcommit_anon
  * INPUTS
  *      loc_id - file or group identifier
  *              dtype_id - dataset identifier
@@ -2136,9 +2105,9 @@ nh5tcommit_anon_c(hid_t_f *loc_id, hid_t_f *dtype_id,
 
 /****if* H5Tf/h5tcommitted_c
  * NAME
- *        h5tcommitted_c
+ *  h5tcommitted_c
  * PURPOSE
- *     Call H5Tcommitted
+ *  Call H5Tcommitted
  *              dtype_id - dataset identifier
  * RETURNS
  *     a positive value, for TRUE, if the datatype has been committed,
@@ -2167,9 +2136,9 @@ nh5tcommitted_c(hid_t_f *dtype_id)
 
 /****if* H5Tf/h5tdecode_c
  * NAME
- *        h5tdecode_c
+ *  h5tdecode_c
  * PURPOSE
- *     Call H5Tdecode
+ *  Call H5Tdecode
  * INPUTS
  *
  *		buf     - Buffer for the data space object to be decoded.
@@ -2213,9 +2182,9 @@ nh5tdecode_c ( _fcd buf, hid_t_f *obj_id )
 
 /****if* H5Tf/h5tencode_c
  * NAME
- *        h5tencode_c
+ *  h5tencode_c
  * PURPOSE
- *     Call H5Tencode
+ *  Call H5Tencode
  * INPUTS
  *
  *            obj_id - Identifier of the object to be encoded.
@@ -2283,9 +2252,9 @@ nh5tencode_c (_fcd buf, hid_t_f *obj_id, size_t_f *nalloc )
 
 /****if* H5Tf/h5tget_create_plist_c
  * NAME
- *        h5tget_create_plist_c
+ *  h5tget_create_plist_c
  * PURPOSE
- *     Call H5Tget_create_plist
+ *  Call H5Tget_create_plist
  * INPUTS
  *      dtype_id          - Datatype identifier
  * OUTPUTS
@@ -2315,9 +2284,9 @@ nh5tget_create_plist_c ( hid_t_f *dtype_id,  hid_t_f *dtpl_id)
 
 /****if* H5Tf/h5tcompiler_conv_c
  * NAME
- *        h5tcompiler_conv_c
+ *  h5tcompiler_conv_c
  * PURPOSE
- *     Call H5Tcompiler_conv
+ *  Call H5Tcompiler_conv
  * INPUTS
  *
  *              src_id - Identifier for the source datatype.
@@ -2349,9 +2318,9 @@ nh5tcompiler_conv_c ( hid_t_f *src_id, hid_t_f *dst_id, int_f *c_flag)
 }
 /****if* H5Tf/h5tget_native_type_c
  * NAME
- *        h5tget_native_type_c
+ *  h5tget_native_type_c
  * PURPOSE
- *     Call H5Tget_native_type
+ *  Call H5Tget_native_type
  * INPUTS
  *
  *              dtype_id         - Datatype identifier for the dataset datatype.
@@ -2384,9 +2353,9 @@ nh5tget_native_type_c(hid_t_f *dtype_id, int_f *direction, hid_t_f *native_dtype
 
 /****if* H5Tf/h5tconvert_c
  * NAME
- *        h5tconvert_c
+ *  h5tconvert_c
  * PURPOSE
- *     Call H5Tconvert
+ *  Call H5Tconvert
  * INPUTS
  *
  *  src_id     - Identifier for the source datatype.
@@ -2400,7 +2369,7 @@ nh5tget_native_type_c(hid_t_f *dtype_id, int_f *direction, hid_t_f *native_dtype
  *  buf        - Array containing post-conversion values.
  *
  * RETURNS
- *     0 on success, -1 on failure
+ *  0 on success, -1 on failure
  * AUTHOR
  *  M. Scot Breitenfeld
  *  December 8, 2008
@@ -2408,7 +2377,7 @@ nh5tget_native_type_c(hid_t_f *dtype_id, int_f *direction, hid_t_f *native_dtype
  * SOURCE
 */
 int_f
-nh5tconvert_c(hid_t_f *src_id, hid_t_f *dst_id, size_t_f *nelmts, void *buf, void *background, hid_t_f *plist_id)
+h5tconvert_c(hid_t_f *src_id, hid_t_f *dst_id, size_t_f *nelmts, void *buf, void *background, hid_t_f *plist_id)
 /******/
 {
   int ret_value = -1;
@@ -2420,3 +2389,44 @@ nh5tconvert_c(hid_t_f *src_id, hid_t_f *dst_id, size_t_f *nelmts, void *buf, voi
   return ret_value;
 }
 
+/****if* H5Tf/h5tenum_insert_ptr_c
+ * NAME
+ *  /h5tenum_insert_ptr_c
+ * PURPOSE
+ *  Calls H5Tenum_insert
+ * INPUTS
+ *  type_id  - Datatype identifier for the enumeration datatype.
+ *  name     - Datatype identifier.
+ *  value    - Pointer to the value of the new member.
+ *
+ * OUTPUTS
+ *
+ * RETURNS
+ *  0 on success, -1 on failure
+ * AUTHOR
+ *  M. Scot Breitenfeld
+ *  February 6, 2015
+ *
+ * SOURCE
+*/
+int_f
+h5tenum_insert_ptr_c(hid_t_f *type_id, _fcd name, int_f* namelen, void *value)
+/******/
+{
+  int ret_value = -1;
+  hid_t status;
+  char *c_name;
+
+  /*
+   * Convert FORTRAN name to C name
+   */
+  c_name = (char *)HD5f2cstring(name, (size_t)*namelen);
+  if (c_name == NULL) return ret_value;
+
+  status = H5Tenum_insert( (hid_t)*type_id, c_name, value);
+  if ( status < 0  ) return ret_value;
+  ret_value = 0;
+  return ret_value;
+}
+
+
