@@ -44,6 +44,8 @@
 MODULE H5GLOBAL
   USE H5FORTRAN_TYPES
 
+  IMPLICIT NONE
+
   ! Definitions for reference datatypes.
   ! If you change the value of these parameters, do not forget to change corresponding
   ! values in the H5f90.h file.
@@ -232,6 +234,8 @@ MODULE H5GLOBAL
   !
   ! H5F flags (DO NOT FORGET TO UPDATE WHEN NEW FLAGS ARE ADDED !)
   !
+  ! H5F_ACC_DEBUG_F has no effect as of HDF5 1.8.16
+  !
   ! H5F flags declaration
   !
   INTEGER, PARAMETER :: H5F_FLAGS_LEN = 19
@@ -309,8 +313,6 @@ MODULE H5GLOBAL
   EQUIVALENCE(H5generic_flags(7), H5_ITER_DEC_F)
   EQUIVALENCE(H5generic_flags(8), H5_ITER_NATIVE_F)
   EQUIVALENCE(H5generic_flags(9), H5_ITER_N_F)
-
-
   !
   ! H5G flags declaration
   !
@@ -325,8 +327,9 @@ MODULE H5GLOBAL
   INTEGER :: H5G_GROUP_F
   INTEGER :: H5G_DATASET_F
   INTEGER :: H5G_TYPE_F
-  ! XXX: Fix problems with H5G_LINK_F! - QAK
   INTEGER :: H5G_LINK_F
+  INTEGER :: H5G_UDLINK_F
+  INTEGER :: H5G_SAME_LOC_F
   INTEGER :: H5G_LINK_ERROR_F
   INTEGER :: H5G_LINK_HARD_F
   INTEGER :: H5G_LINK_SOFT_F
@@ -335,16 +338,14 @@ MODULE H5GLOBAL
   INTEGER :: H5G_STORAGE_TYPE_COMPACT_F
   INTEGER :: H5G_STORAGE_TYPE_DENSE_F
 
-  EQUIVALENCE(H5G_flags(1), H5G_UNKNOWN_F)
-  EQUIVALENCE(H5G_flags(2), H5G_GROUP_F)
-  EQUIVALENCE(H5G_flags(3), H5G_DATASET_F)
-  EQUIVALENCE(H5G_flags(4), H5G_TYPE_F)
-  ! XXX: Fix problems with H5G_LINK_F! - QAK ! these are really H5L values -MSB-
-  EQUIVALENCE(H5G_flags(5), H5G_LINK_F)
+  EQUIVALENCE(H5G_flags(1), H5G_UNKNOWN_F) ! Unknown object type
+  EQUIVALENCE(H5G_flags(2), H5G_GROUP_F)   ! Object is a group
+  EQUIVALENCE(H5G_flags(3), H5G_DATASET_F) ! Object is a dataset
+  EQUIVALENCE(H5G_flags(4), H5G_TYPE_F)    ! Object is a named data type
+  EQUIVALENCE(H5G_flags(5), H5G_SAME_LOC_F)
   EQUIVALENCE(H5G_flags(6), H5G_LINK_ERROR_F)
   EQUIVALENCE(H5G_flags(7), H5G_LINK_HARD_F)
   EQUIVALENCE(H5G_flags(8), H5G_LINK_SOFT_F)
-  ! XXX
 
   EQUIVALENCE(H5G_flags(9), H5G_STORAGE_TYPE_UNKNOWN_F )
   EQUIVALENCE(H5G_flags(10), H5G_STORAGE_TYPE_SYMBOL_TABLE_F)
@@ -574,7 +575,7 @@ MODULE H5GLOBAL
   !
   ! H5O flags declaration
   !
-  INTEGER, PARAMETER :: H5O_FLAGS_LEN = 22
+  INTEGER, PARAMETER :: H5O_FLAGS_LEN = 27
   INTEGER :: H5o_flags(H5O_FLAGS_LEN)
   !DEC$if defined(BUILD_HDF5_DLL)
   !DEC$ATTRIBUTES DLLEXPORT :: /H5O_FLAGS/
@@ -603,6 +604,11 @@ MODULE H5GLOBAL
   INTEGER :: H5O_HDR_ALL_FLAGS_F
   INTEGER :: H5O_SHMESG_MAX_NINDEXES_F
   INTEGER :: H5O_SHMESG_MAX_LIST_SIZE_F
+  INTEGER :: H5O_TYPE_UNKNOWN_F
+  INTEGER :: H5O_TYPE_GROUP_F
+  INTEGER :: H5O_TYPE_DATASET_F
+  INTEGER :: H5O_TYPE_NAMED_DATATYPE_F
+  INTEGER :: H5O_TYPE_NTYPES_F
 
   EQUIVALENCE(h5o_flags(1) , H5O_COPY_SHALLOW_HIERARCHY_F)
   EQUIVALENCE(h5o_flags(2) , H5O_COPY_EXPAND_SOFT_LINK_F)
@@ -626,6 +632,11 @@ MODULE H5GLOBAL
   EQUIVALENCE(h5o_flags(20) , H5O_HDR_ALL_FLAGS_F)
   EQUIVALENCE(h5o_flags(21) , H5O_SHMESG_MAX_NINDEXES_F)
   EQUIVALENCE(h5o_flags(22) , H5O_SHMESG_MAX_LIST_SIZE_F)
+  EQUIVALENCE(h5o_flags(23) , H5O_TYPE_UNKNOWN_F)
+  EQUIVALENCE(h5o_flags(24) , H5O_TYPE_GROUP_F)
+  EQUIVALENCE(h5o_flags(25) , H5O_TYPE_DATASET_F)
+  EQUIVALENCE(h5o_flags(26) , H5O_TYPE_NAMED_DATATYPE_F)
+  EQUIVALENCE(h5o_flags(27) , H5O_TYPE_NTYPES_F)
 
   !
   ! H5P flags declaration
