@@ -2148,7 +2148,7 @@ test_refer_dtype(hid_t file)
         TEST_ERROR;
 
     /* Create reference to named datatype */
-    if(H5Rcreate(wbuf, file, "/Group1/Datatype1", H5R_OBJECT, -1) < 0)
+    if(H5Rcreate(wbuf, file, "/Group1/Datatype1", H5R_OBJECT, (hid_t)-1) < 0)
         TEST_ERROR;
     if(H5Rget_obj_type2(dataset, H5R_OBJECT, wbuf, &obj_type) < 0)
         TEST_ERROR;
@@ -2605,7 +2605,7 @@ test_bitfield_dtype(hid_t file)
 
     if((ntype_size = H5Tget_size(native_type)) == 0) TEST_ERROR;
 
-    rbuf = malloc((size_t)nelmts*ntype_size);
+    rbuf = HDmalloc((size_t)nelmts*ntype_size);
 
     /* Read the data and compare them */
     if(H5Dread(dataset1, native_type, H5S_ALL, H5S_ALL, H5P_DEFAULT, rbuf) < 0) TEST_ERROR;
@@ -2624,7 +2624,7 @@ test_bitfield_dtype(hid_t file)
     if(H5Tclose(dtype) < 0) TEST_ERROR;
     if(H5Tclose(native_type) < 0) TEST_ERROR;
     if(H5Dclose(dataset1) < 0) TEST_ERROR;
-    if(rbuf) free(rbuf);
+    if(rbuf) HDfree(rbuf);
 
     /* Open dataset2 again to check H5Tget_native_type */
     if((dataset2 = H5Dopen2(file, DSET2_BITFIELD_NAME, H5P_DEFAULT)) < 0) TEST_ERROR;
